import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import React, { lazy, useState, useEffect, Suspense } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = "sui-AtomSlider";
var CLASS_DISABLED = BASE_CLASS + "--disabled";
var Range = lazy(function () {
  return import('rc-slider/lib/Range');
});
var Slider = lazy(function () {
  return import('rc-slider/lib/Slider');
});
var Tooltip = lazy(function () {
  return import('rc-tooltip');
});

var createHandler = function createHandler(refAtomSlider, handleComponent) {
  return function (props) {
    var value = props.value,
        index = props.index,
        dragging = props.dragging,
        restProps = _objectWithoutPropertiesLoose(props, ["value", "index", "dragging"]); // eslint-disable-line


    var Handle = handleComponent.component;
    return React.createElement(Tooltip, {
      getTooltipContainer: function getTooltipContainer() {
        return refAtomSlider.current;
      },
      key: index,
      overlay: value,
      placement: "top",
      prefixCls: "rc-slider-tooltip",
      visible: true
    }, React.createElement(Handle, Object.assign({
      value: value
    }, restProps, {
      dragging: dragging.toString()
    })));
  };
};

var AtomSlider = function AtomSlider(_ref) {
  var _ref3, _cx;

  var onChange = _ref.onChange,
      value = _ref.value,
      min = _ref.min,
      max = _ref.max,
      step = _ref.step,
      range = _ref.range,
      disabled = _ref.disabled;

  var _useState = useState(false),
      ready = _useState[0],
      setReady = _useState[1];

  var _useState2 = useState({
    component: null
  }),
      handleComponent = _useState2[0],
      setHandle = _useState2[1];

  var refAtomSlider = React.createRef();
  useEffect(function () {
    // import Handle here and set it in the state as tooltip need this to be loaded
    // before trying to be shown, otherwise, the reference is wrong
    // and the tooltip is not positioned correctly
    import('rc-slider/lib/Handle').then(function (_ref2) {
      var Handle = _ref2.default;
      setHandle({
        component: Handle
      });
      setReady(true);
    });
  }, []);

  var handleChange = function handleChange(value) {
    var e = {};
    onChange(e, {
      value: value
    });
  };

  var numTicks = Math.round((max - min) / step) + 1;
  var steps = Array.from(Array(numTicks), function (x, index) {
    return index * step;
  });
  var marks = step === 1 ? (_ref3 = {}, _ref3[min] = min, _ref3[max] = max, _ref3) : steps.reduce(function (marksConfig, step) {
    marksConfig[step] = step;
    return marksConfig;
  }, {});
  var customProps = {
    defaultValue: range ? [min, max] : value,
    handle: createHandler(refAtomSlider, handleComponent),
    onChange: handleChange,
    disabled: disabled,
    marks: marks,
    max: max,
    min: min,
    step: step // Determine the type of the slider according to the range prop

  };
  var Type = range ? Range : Slider;
  return React.createElement("div", {
    ref: refAtomSlider,
    className: cx(BASE_CLASS, (_cx = {}, _cx[CLASS_DISABLED] = disabled, _cx))
  }, ready && React.createElement(Suspense, {
    fallback: null
  }, React.createElement(Type, customProps)));
};

AtomSlider.displayName = 'AtomSlider';
AtomSlider.defaultProps = {
  min: 0,
  max: 100,
  step: 1,
  onChange: function onChange() {}
};
export default AtomSlider;